{% extends 'base.html' %}

{% block page_title %}Delete Budget{% endblock %}

{% block content %}
    <h2>Delete Budget</h2>
    
    <p>Are you sure you want to delete "{{ budget }}"?</p>
    
    <form method="post" action=".">
        <table class="form_table">
            <tr>
                <td>
                    <input type="submit" name="confirmed" value="Yes">
                    or
                    <input type="button" name="do_not_delete" value="No">
                </td>
            </tr>
        </table>
    </form>
{% endblock %}