{% extends 'budget/base.html' %}

{% block title %}Add A Transaction{% endblock %}

{% block budget_content %}
    <h2>Add A Transaction</h2>
    
    <form method="post" action=".">{% csrf_token %}
        <table class="form_table">
            {{ form.as_table }}
            <tr>
                <td>&nbsp;</td>
                <td>
                    <input class="btn btn-primary"  type="submit" name="confirmed" value="Save">
                    or
                    <a href="{% url 'budget_transaction_list' %}">Cancel</a>
                </td>
            </tr>
        </table>
    </form>
{% endblock budget_content %}
